/*
 * Copyright (c) 2014, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/*
 *  ======== pwmled.c ========
 */
/* XDCtools Header files */
#include <xdc/std.h>
#include <xdc/cfg/global.h>
#include <xdc/runtime/System.h>

/* BIOS Header files */
#include <ti/sysbios/BIOS.h>

/* TI-RTOS Header files */
#include <ti/drivers/PWM.h>

/* Example/Board Header files */
#include "Board.h"

/*
 *  ======== pwmLEDFxn ========
 *  Task periodically increments the PWM duty for the on board LED.
 */
Void pwmLEDFxn(UArg arg0, UArg arg1)
{
    PWM_Handle pwm1;
    PWM_Handle pwm2;
    PWM_Handle pwm3;
    PWM_Handle pwm4;
    PWM_Params params;
    uint16_t   pwmPeriod = 20000;      // Period and duty in microseconds
    uint16_t   duty = 0;
    uint16_t   dutyInc = 100;
    uint16_t   dutyARM = 1000;
    uint16_t   dutyCALH = 2000;
    uint16_t   dutyCALL = 1000;
    uint16_t   dutyRUN_PF0 = 1050;
    uint16_t   dutyRUN_PF1 = 1250;
    uint16_t   dutyRUN_PF2 = 1500;
    uint16_t   dutyRUN_PF3 = 1850;

    uint16_t   CAL_time = 2000;
    uint16_t   arm_time = 3000;


    PWM_Params_init(&params);
    params.period = pwmPeriod;
    pwm1 = PWM_open(Board_PWM1, &params);
    if (pwm1 == NULL) {
        System_abort("PWM0 did not open");
    }

    if (Board_PWM1 != Board_PWM0) {
     //   params.polarity = PWM_POL_ACTIVE_LOW;
        pwm2 = PWM_open(Board_PWM0, &params);
    }
    pwm3 = PWM_open(Board_PWM2, &params);
    pwm4 = PWM_open(Board_PWM3, &params);

    /* Loop forever incrementing the PWM duty */
 //   while (1) {
        PWM_setDuty(pwm1, dutyCALH);

        if (pwm2) {
            PWM_setDuty(pwm2, dutyCALH);
        }
        Task_sleep((uint16_t) CAL_time);
        PWM_setDuty(pwm1, dutyCALL);

                if (pwm2) {
                    PWM_setDuty(pwm2, dutyCALL);
                }

//        duty = (duty + dutyInc);
 //       if (duty == pwmPeriod || (!duty)) {
 //           dutyInc = - dutyInc;
 //       }

        Task_sleep((uint16_t) CAL_time);

        PWM_setDuty(pwm1, dutyARM);

               if (pwm2) {
                   PWM_setDuty(pwm2, dutyARM);
               }

         Task_sleep((uint16_t) arm_time);

	 PWM_setDuty(pwm1, dutyRUN_PF0);

	   if (pwm2) {
		   PWM_setDuty(pwm2, dutyRUN_PF1);
	   }

	   PWM_setDuty(pwm3, dutyRUN_PF2);
	   PWM_setDuty(pwm4, dutyRUN_PF3);
  //  }
}

/*
 *  ======== main ========
 */
int main(void)
{
    /* Call board init functions. */
    Board_initGeneral();
    Board_initGPIO();
    Board_initPWM();

    /* Turn on user LED */
    GPIO_write(Board_LED0, Board_LED_ON);

    System_printf("Starting the example\nSystem provider is set to SysMin. "
                  "Halt the target to view any SysMin contents in ROV.\n");

    /* SysMin will only print to the console when you call flush or exit */
    System_flush();

    /* Start BIOS */
    BIOS_start();

    return (0);
}
